general package
===============

general.optimisation.elements module
------------------------------------

.. automodule:: omegalpes.general.optimisation.elements
    :members:
    :undoc-members:
    :show-inheritance:

general.optimisation.model module
---------------------------------

.. automodule:: omegalpes.general.optimisation.model
    :members:
    :undoc-members:
    :show-inheritance:

general.optimisation.units module
---------------------------------

.. automodule:: omegalpes.general.optimisation.units
    :members:
    :undoc-members:
    :show-inheritance:

general.plots module
--------------------

.. automodule:: omegalpes.general.plots
    :members:
    :undoc-members:
    :show-inheritance:

general.time module
-------------------

.. automodule:: omegalpes.general.time
    :members:
    :undoc-members:
    :show-inheritance:
